==> kubernetes-model-1.0.60-sources.jar: annotations/io/fabric8/openshift/api/model/ImageChangeCauseBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class ImageChangeCauseBuilder extends ImageChangeCauseFluentImpl<ImageChangeCauseBuilder> implements VisitableBuilder<ImageChangeCause,ImageChangeCauseBuilder>{

    ImageChangeCauseFluent<?> fluent;
    Boolean validationEnabled;

    public ImageChangeCauseBuilder(){
            this(true);
    }
    public ImageChangeCauseBuilder(Boolean validationEnabled){
            this(new ImageChangeCause(), validationEnabled);
    }
    public ImageChangeCauseBuilder(ImageChangeCauseFluent<?> fluent){
            this(fluent, true);
    }
    public ImageChangeCauseBuilder(ImageChangeCauseFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ImageChangeCause(), validationEnabled);
    }
    public ImageChangeCauseBuilder(ImageChangeCauseFluent<?> fluent,ImageChangeCause instance){
            this(fluent, instance, true);
    }
    public ImageChangeCauseBuilder(ImageChangeCauseFluent<?> fluent,ImageChangeCause instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withFromRef(instance.getFromRef()); 
            fluent.withImageID(instance.getImageID()); 
            this.validationEnabled = validationEnabled; 
    }
    public ImageChangeCauseBuilder(ImageChangeCause instance){
            this(instance,true);
    }
    public ImageChangeCauseBuilder(ImageChangeCause instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withFromRef(instance.getFromRef()); 
            this.withImageID(instance.getImageID()); 
            this.validationEnabled = validationEnabled; 
    }

    public ImageChangeCause build(){
            ImageChangeCause buildable = new ImageChangeCause(fluent.getFromRef(),fluent.getImageID());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ImageChangeCauseBuilder that = (ImageChangeCauseBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.64-sources.jar: annotations/io/fabric8/openshift/api/model/ImageChangeCauseBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class ImageChangeCauseBuilder extends ImageChangeCauseFluentImpl<ImageChangeCauseBuilder> implements VisitableBuilder<ImageChangeCause,ImageChangeCauseBuilder>{

    ImageChangeCauseFluent<?> fluent;
    Boolean validationEnabled;

    public ImageChangeCauseBuilder(){
            this(true);
    }
    public ImageChangeCauseBuilder(Boolean validationEnabled){
            this(new ImageChangeCause(), validationEnabled);
    }
    public ImageChangeCauseBuilder(ImageChangeCauseFluent<?> fluent){
            this(fluent, true);
    }
    public ImageChangeCauseBuilder(ImageChangeCauseFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new ImageChangeCause(), validationEnabled);
    }
    public ImageChangeCauseBuilder(ImageChangeCauseFluent<?> fluent,ImageChangeCause instance){
            this(fluent, instance, true);
    }
    public ImageChangeCauseBuilder(ImageChangeCauseFluent<?> fluent,ImageChangeCause instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withFromRef(instance.getFromRef()); 
            fluent.withImageID(instance.getImageID()); 
            this.validationEnabled = validationEnabled; 
    }
    public ImageChangeCauseBuilder(ImageChangeCause instance){
            this(instance,true);
    }
    public ImageChangeCauseBuilder(ImageChangeCause instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withFromRef(instance.getFromRef()); 
            this.withImageID(instance.getImageID()); 
            this.validationEnabled = validationEnabled; 
    }

    public ImageChangeCause build(){
            ImageChangeCause buildable = new ImageChangeCause(fluent.getFromRef(),fluent.getImageID());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ImageChangeCauseBuilder that = (ImageChangeCauseBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
